@@ -7,6 +7,7 @@ module Fqn
 where
 
 -- project imports
+import Location
 import qualified Token
 
 -- general imports
@@ -24,6 +25,7 @@ data Fqn
    | ClassInstance ClassInstanceContent
    | ClassName ClassNameContent
    | FieldedAccess Fqn Token.FieldName
+   | CallMethodOfClass Location String Token.ClassName
    | NativeTypeInt
    | NativeTypeString
    | NativeTypeBool
@@ -80,4 +82,4 @@ data ClassNameContent
      {
          classNameContent :: Token.ClassName
      }
-     deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
\ No newline at end of file
+     deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
